| Title: | Flights that Departed NYC in 2013 |
|---|---|
| Description: | Airline on-time data for all flights departing NYC in 2013. Also includes useful 'metadata' on airlines, airports, weather, and planes. |
| Authors: | Hadley Wickham [aut, cre], Posit Software, PBC [cph, fnd] |
| Maintainer: | Hadley Wickham <[email protected]> |
| License: | CC0 |
| Version: | 1.0.2.9000 |
| Built: | 2026-05-24 06:49:42 UTC |
| Source: | https://github.com/tidyverse/nycflights13 |
Look up airline names from their carrier codes.
airlinesairlines
Data frame with columns
Two letter abbreviation.
Full name.
https://www.transtats.bts.gov/DL_SelectFields.asp?Table_ID=236
airlinesairlines
Useful metadata about airports.
airportsairports
A data frame with columns:
FAA airport code.
Usual name of the airport.
Location of airport.
Altitude, in feet.
Timezone offset from GMT.
Daylight savings time zone. A = Standard US DST: starts on the second Sunday of March, ends on the first Sunday of November. U = unknown. N = no dst.
IANA time zone, as determined by GeoNames webservice.
https://openflights.org/data.html, downloaded 2014-06-27
airports if (require("dplyr")) { airports %>% rename(dest = faa) %>% semi_join(flights) flights %>% anti_join(airports %>% rename(dest = faa)) airports %>% rename(origin = faa) %>% semi_join(flights) }airports if (require("dplyr")) { airports %>% rename(dest = faa) %>% semi_join(flights) flights %>% anti_join(airports %>% rename(dest = faa)) airports %>% rename(origin = faa) %>% semi_join(flights) }
On-time data for all flights that departed NYC (i.e. JFK, LGA or EWR) in 2013.
flightsflights
Data frame with columns
Date of departure.
Actual departure and arrival times (format HHMM or HMM), local tz.
Scheduled departure and arrival times (format HHMM or HMM), local tz.
Departure and arrival delays, in minutes. Negative times represent early departures/arrivals.
Two letter carrier abbreviation. See airlines
to get name.
Flight number.
Plane tail number. See planes for additional metadata.
Origin and destination. See airports for
additional metadata.
Amount of time spent in the air, in minutes.
Distance between airports, in miles.
Time of scheduled departure broken into hour and minutes.
Scheduled date and hour of the flight as a POSIXct date.
Along with origin, can be used to join flights data to weather data.
RITA, Bureau of transportation statistics, https://www.transtats.bts.gov/DL_SelectFields.asp?Table_ID=236
Plane metadata for all plane tailnumbers found in the FAA aircraft registry. American Airways (AA) and Envoy Air (MQ) report fleet numbers rather than tail numbers so can't be matched.
planesplanes
A data frame with columns:
Tail number.
Year manufactured.
Type of plane.
Manufacturer and model.
Number of engines and seats.
Average cruising speed in mph.
Type of engine.
FAA Aircraft registry, https://www.faa.gov/licenses_certificates/aircraft_certification/aircraft_registry/releasable_aircraft_download/
planes if (require("dplyr")) { # Flights that don't have plane metadata flights %>% anti_join(planes, "tailnum") }planes if (require("dplyr")) { # Flights that don't have plane metadata flights %>% anti_join(planes, "tailnum") }
Hourly meteorological data for LGA, JFK and EWR.
weatherweather
A data frame with columns:
Weather station. Named origin to facilitate merging with
flights data.
Time of recording.
Temperature and dewpoint in F.
Relative humidity.
Wind direction (in degrees), speed and gust speed (in mph).
Precipitation, in inches.
Sea level pressure in millibars.
Visibility in miles.
Date and hour of the recording as a POSIXct date.
ASOS download from Iowa Environmental Mesonet, https://mesonet.agron.iastate.edu/request/download.phtml.